# Generated by Django 2.2.12 on 2020-06-13 00:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fleet', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='fleet',
            name='name',
            field=models.CharField(default='', max_length=50),
        ),
    ]
