{% extends 'allianceauth/base.html' %}
{% load i18n %}

{% block page_title %}{% trans "fleet" %}{% endblock %}

{% block content %}
    <div class="col-lg-12">
        <br />
        <div class="col-lg-12 container">
            <nav class="navbar navbar-default">
                <div class="container-fluid">
                    <div class="navbar-header">
                        <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                            <span class="sr-only">{% trans "Toggle navigation" %}</span>
                            <span class="icon-bar"></span>
                            <span class="icon-bar"></span>
                            <span class="icon-bar"></span>
                        </button>
                        <a class="navbar-brand" href="{% url 'fleet:dashboard' %}">{% trans "Available Fleets" %}</a>
                    </div>
                    <ul class="nav navbar-nav navbar-right">
                        {% if perms.fleet.manage %}
                            <li> <a href="{% url 'fleet:create_fleet' %}">Create Fleet</a></li>
                        {% endif %}
                    </ul>
                </div>
            </nav>
            {% block fleet_block %}{% endblock %}
        </div>
    </div>
{% endblock %}

